@@ -52,11 +52,12 @@ def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule:
     KineticlibError
         if `deg > 1`
     """
-    return raw_diss_integral_rigid_sphere(T, deg, idata, molecule.vibr[i], molecule.diss, center_of_mass,
+    return raw_diss_integral_rigid_sphere(T, deg, idata[1], idata[0], molecule.vibr[i], molecule.diss, center_of_mass,
                                           vl_dependent, nokt)
 
 
-def elastic_integral(T: float, deg: int, idata: np.ndarray, rig_sphere: bool=False, nokt: bool=False) -> float:
+def elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: float, vsso: float,
+                     rig_sphere: bool=False, nokt: bool=False) -> float:
     """Calculates the generalized elastic omega integral either using the rigid sphere model or the VSS model
 
     Parameters
@@ -65,8 +66,14 @@ def elastic_integral(T: float, deg: int, idata: np.ndarray, rig_sphere: bool=Fal
         the temperature of the mixture
     deg : int
         the degree of the omega integral
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     molecule : Molecule
         the molecule which dissociates
     rig_sphere : bool, optional
@@ -80,18 +87,15 @@ def elastic_integral(T: float, deg: int, idata: np.ndarray, rig_sphere: bool=Fal
     float
         The generalized omega integral over the elastic crosssection
     """
-    if rig_sphere is False:
-        if nokt is False:
-            multiplier = idata[9] * ((T * constants.k / (2.0 * constants.pi * idata[0])) ** 0.5) * (T ** (-idata[10]))
-        else:
-            multiplier = idata[9] * ((0.5 / (constants.pi * idata[0])) ** 0.5) * (T ** (-idata[10]))
-        return 0.5 * gamma(2.0 - idata[10] + deg) * (constants.physical_constants['Angstrom star'][0] ** 2) * multiplier
+    if nokt is False:
+        multiplier = ((T * constants.k / (2.0 * constants.pi * mass)) ** 0.5)
     else:
-        if nokt is False:
-            multiplier = ((T * constants.k / (2.0 * constants.pi * idata[0])) ** 0.5)
-        else:
-            multiplier = ((0.5 / (constants.pi * idata[0])) ** 0.5)
-        return 0.5 * multiplier * constants.pi * gamma(0.5 * deg + 2.0) * (idata[1] ** 2)
+        multiplier = ((0.5 / (constants.pi * mass)) ** 0.5)
+    if rig_sphere is False:
+        return 0.5 * multiplier * gamma(2.0 - vsso + deg) * (constants.physical_constants['Angstrom star'][0] ** 2)\
+                   * vssc * (T ** (-vsso))
+    else:
+        return 0.5 * multiplier * constants.pi * gamma(0.5 * deg + 2.0) * (sigma ** 2)
 
 
 def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int,
@@ -127,7 +131,8 @@ def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i:
         if `delta == 0`
     
     """
-    return raw_vt_integral(T, deg, idata, molecule.vibr, molecule.vibr_zero, molecule.diss, i, delta, nokt)
+    return raw_vt_integral(T, deg, idata[0], idata[4], idata[9], idata[10], molecule.vibr,
+                           molecule.vibr_zero, molecule.diss, i, delta, nokt)
 
 
 def vv_integral(T: float, deg: int, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS, i: int,
@@ -167,7 +172,8 @@ def vv_integral(T: float, deg: int, idata: np.ndarray, molecule1: MoleculeSTS, m
         if `i_delta == 0`
     
     """
-    return raw_vv_integral(T, deg, idata, molecule1.vibr, molecule2.vibr, i, k, i_delta, nokt)
+    return raw_vv_integral(T, deg, idata[0], idata[4], idata[9], idata[10],
+                           molecule1.vibr, molecule2.vibr, i, k, i_delta, nokt)
 
 
 def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecule1: Molecule, molecule2: Molecule,
@@ -224,7 +230,8 @@ def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecul
     b = np.arange(0, molecule2.num_vibr_levels(T, T1_2, True) + 1)
     vibr_exp = molecule1.vibr_exp(a, T, T1_1)
     vibr_exp2 = molecule2.vibr_exp(b, T, T1_2)
-    return raw_vv_collisions(T, idata, molecule1.Z_vibr(T, T1_1), molecule2.Z_vibr(T, T1_2),
+    return raw_vv_collisions(T, idata[0], idata[4], idata[9], idata[10],
+                             molecule1.Z_vibr(T, T1_1), molecule2.Z_vibr(T, T1_2),
                              molecule1.vibr, molecule2.vibr, vibr_exp, vibr_exp2,
                              molecule1.num_vibr, molecule2.num_vibr, nokt)
 
@@ -284,7 +291,8 @@ def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integ
     float
         The calculated averaging
     """
-    return raw_dE_rot_single(T, idata, molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const, molecule.num_rot,
+    return raw_dE_rot_single(T, idata[1], idata[0], idata[9], idata[10],
+                             molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const, molecule.num_rot,
                              full_integral, nokt)
 
 
@@ -317,7 +325,8 @@ def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molec
     float
         The calculated averaging
     """
-    return raw_dE_rot_c_dE_rot_d(T, idata, molecule1.Z_rot(T), molecule2.Z_rot(T), molecule1.rot_symmetry,
+    return raw_dE_rot_c_dE_rot_d(T, idata[1], idata[0], idata[9], idata[10],
+                                 molecule1.Z_rot(T), molecule2.Z_rot(T), molecule1.rot_symmetry,
                                  molecule2.rot_symmetry, molecule1.rot_const, molecule2.rot_const, molecule1.num_rot,
                                  molecule2.num_rot, full_integral, nokt)
 
@@ -353,16 +362,17 @@ def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: MoleculeSTS, mole
     float
         The calculated averaging
     """
-    return raw_dE_rot_dE_rot_full(T, idata, molecule1.Z_rot(T), molecule2.Z_rot(T), molecule1.rot_symmetry,
+    return raw_dE_rot_dE_rot_full(T, idata[1], idata[0], idata[9], idata[10],
+                                  molecule1.Z_rot(T), molecule2.Z_rot(T), molecule1.rot_symmetry,
                                   molecule2.rot_symmetry, molecule1.rot_const, molecule2.rot_const, molecule1.num_rot,
                                   molecule2.num_rot, full_integral, nokt)
 
 
-def raw_diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule_vibr: float,
+def raw_diss_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float, molecule_vibr: float,
                                    molecule_diss: float, center_of_mass: bool=True, vl_dependent: bool=True,
                                    nokt: bool=False) -> float:
     """Calculates the generalized dissociation omega integral either using the rigid sphere model or the rigid sphere
-    model depending on the relative energy along the center-of-mass line
+    model depending on the relative energy along the center-of-mass line, *raw* version
 
     Parameters
     ----------
@@ -370,8 +380,10 @@ def raw_diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecu
         the temperature of the mixture
     deg : int
         the degree of the omega integral
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates
     molecule_diss : float
@@ -396,9 +408,9 @@ def raw_diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecu
         if `deg > 1`
     """
     if nokt is False:
-        multiplier = constants.pi * (idata[1] ** 2) * ((constants.k * T / (2 * constants.pi * idata[0])) ** 0.5)
+        multiplier = constants.pi * (sigma ** 2) * ((constants.k * T / (2 * constants.pi * mass)) ** 0.5)
     else:
-        multiplier = constants.pi * (idata[1] ** 2) * ((0.5 / (constants.pi * idata[0])) ** 0.5)
+        multiplier = constants.pi * (sigma ** 2) * ((0.5 / (constants.pi * mass)) ** 0.5)
     if vl_dependent is True:
         min_sq = (molecule_diss - molecule_vibr) / (constants.k * T)
     else:
@@ -407,12 +419,12 @@ def raw_diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecu
         if center_of_mass is False:
             return 0.5 * multiplier * np.exp(-min_sq)
         else:
-            return multiplier * 0.5 * (min_sq + 1.0) * np.exp(-min_sq)
+            return 0.5 * multiplier * (min_sq + 1.0) * np.exp(-min_sq)
     elif deg == 1:
         if center_of_mass is False:
             return 0.5 * multiplier * (min_sq + 2.0) * np.exp(-min_sq)
         else:
-            return multiplier * 0.5 * ((min_sq ** 2) + 2.0 * min_sq + 1.0) * np.exp(-min_sq)
+            return 0.5 * multiplier * ((min_sq ** 2) + 2.0 * min_sq + 1.0) * np.exp(-min_sq)
     else:
         raise KineticlibError('Cannot calculated generalized dissociation omega integral of degree ' + str(deg))
 
@@ -437,9 +449,9 @@ def elastic_crosssection(g: float, deg: int, vsso: float) -> float:
     return np.exp(-(g ** 2)) * (g ** (3 + 2 * (deg - vsso)))
 
 
-def raw_vt_integral(T: float, deg: int, idata: np.ndarray, molecule_vibr_array: np.ndarray, molecule_vibr_zero: float,
-                    molecule_diss: float, i: int, delta: int,
-                    nokt: bool=False) -> float:
+def raw_vt_integral(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
+                    molecule_vibr_array: np.ndarray, molecule_vibr_zero: float, molecule_diss: float, i: int,
+                    delta: int, nokt: bool=False) -> float:
     """Calculates the generalized VT omega integral using the FHO probability and VSS cross-section models
     for the following process: M(i) + P -> M(i + delta) + P, *raw* version
 
@@ -449,8 +461,14 @@ def raw_vt_integral(T: float, deg: int, idata: np.ndarray, molecule_vibr_array:
         the temperature of the mixture
     deg : int
         the degree of the omega integral
-    idata : 1-D array-like
-        the array of interaction data
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     molecule_vibr_array : 1-D array-like
         the array of vibrational energies of the molecule undergoing the VT transition
     molecule_vibr_zero : float
@@ -476,8 +494,9 @@ def raw_vt_integral(T: float, deg: int, idata: np.ndarray, molecule_vibr_array:
 
     """
     if delta != 0:
-        f = lambda g: prob.vt_prob_g_only(g, T, idata, molecule_vibr_array, i, delta,
-                                          molecule_vibr_zero + molecule_diss) * elastic_crosssection(g, deg, idata[10])
+        f = lambda g: prob.vt_prob_g_only(g, T, mass, beta, molecule_vibr_array[i], molecule_vibr_array[i + delta],
+                                          i, delta, molecule_vibr_zero + molecule_diss)\
+                      * elastic_crosssection(g, deg, vsso)
         if delta == 1:
             mult = (i + 1)
         elif delta == -1:
@@ -487,19 +506,20 @@ def raw_vt_integral(T: float, deg: int, idata: np.ndarray, molecule_vibr_array:
         else:
             mult = prob.fact_div_fact(i + delta, i) / (factorial(-delta) ** 2)
         if nokt is False:
-            return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * idata[9]\
-                        * ((T * constants.k / (2.0 * constants.pi * idata[0])) ** 0.5) * (T ** (-idata[10]))\
+            return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * vssc\
+                        * ((T * constants.k / (2.0 * constants.pi * mass)) ** 0.5) * (T ** (-vsso))\
                         * integrate.quad(f, 0, np.inf)[0]
         else:
-            return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * idata[9]\
-                        * ((0.5 / (constants.pi * idata[0])) ** 0.5) * (T ** (-idata[10]))\
+            return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * vssc\
+                        * ((0.5 / (constants.pi * mass)) ** 0.5) * (T ** (-vsso))\
                         * integrate.quad(f, 0, np.inf)[0]
     else:
         raise KineticlibError('VT transition with no change in vibrational level specified')
 
 
-def raw_vv_integral(T: float, deg: int, idata: np.ndarray, molecule_vibr_array1: np.ndarray,
-                    molecule_vibr_array2: np.ndarray, i: int, k: int, i_delta: int, nokt=False) -> float:
+def raw_vv_integral(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
+                    molecule_vibr_array1: np.ndarray, molecule_vibr_array2: np.ndarray, i: int, k: int,
+                    i_delta: int, nokt=False) -> float:
     """Calculates the generalized VV omega integral using the FHO probability and VSS cross-section models
     for the following process: M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta), *raw* version
 
@@ -509,8 +529,14 @@ def raw_vv_integral(T: float, deg: int, idata: np.ndarray, molecule_vibr_array1:
         the temperature of the mixture
     deg : int
         the degree of the omega integral
-    idata : 1-D array-like
-        the array of interaction data
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     molecule_vibr_array1 : 1-D array-like
         the array of vibrational energies of the molecule M1
     molecule_vibr_array2 : 1-D array-like
@@ -536,8 +562,9 @@ def raw_vv_integral(T: float, deg: int, idata: np.ndarray, molecule_vibr_array1:
 
     """
     if i_delta != 0:
-        f = lambda g: prob.vv_prob_g_only(g, T, idata, molecule_vibr_array1, molecule_vibr_array2, i, k, i_delta) \
-                      * elastic_crosssection(g, deg, idata[10])
+        f = lambda g: prob.vv_prob_g_only(g, T, mass, beta, molecule_vibr_array1[i], molecule_vibr_array1[i + i_delta],
+                                          molecule_vibr_array2[k], molecule_vibr_array2[k - i_delta], i, k, i_delta) \
+                      * elastic_crosssection(g, deg, vsso)
         if i_delta == 1:
             mult = (i + 1) * k
         elif i_delta == -1:
@@ -547,18 +574,19 @@ def raw_vv_integral(T: float, deg: int, idata: np.ndarray, molecule_vibr_array1:
         else:
             mult = prob.fact_div_fact(i + i_delta, i) * prob.fact_div_fact(k, k - i_delta) / (factorial(-i_delta) ** 2)
         if nokt is False:
-            return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * idata[9]\
-                        * ((T * constants.k / (2.0 * constants.pi * idata[0])) ** 0.5) * (T ** (-idata[10]))\
+            return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * vssc\
+                        * ((T * constants.k / (2.0 * constants.pi * mass)) ** 0.5) * (T ** (-vsso))\
                         * integrate.quad(f, 0, np.inf)[0]
         else:
-            return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * idata[9]\
-                        * ((0.5 / (constants.pi * idata[0])) ** 0.5) * (T ** (-idata[10]))\
+            return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * vssc\
+                        * ((0.5 / (constants.pi * mass)) ** 0.5) * (T ** (-vsso))\
                         * integrate.quad(f, 0, np.inf)[0]
     else:
         raise KineticlibError('VV transition with no change in vibrational level specified')
 
 
-def raw_vv_collisions(T: float, idata: np.ndarray, Z_vibr1: float, Z_vibr2: float,
+def raw_vv_collisions(T: float, mass: float, beta: float, vssc: float, vsso: float,
+                      Z_vibr1: float, Z_vibr2: float,
                       molecule_vibr_array1: np.ndarray, molecule_vibr_array2: np.ndarray,
                       molecule_vibr_exp_array1: np.ndarray, molecule_vibr_exp_array2: np.ndarray,
                       molecule_num_vibr1: int, molecule_num_vibr2: int,
@@ -587,8 +615,14 @@ def raw_vv_collisions(T: float, idata: np.ndarray, Z_vibr1: float, Z_vibr2: floa
         the temperature of the mixture
     deg : int
         the degree of the omega integral
-    idata : 1-D array-like
-        the array of interaction data
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_vibr1 : float
         the value of the vibrational partition function of the molecule M1
     Z_vibr2 : float
@@ -625,7 +659,8 @@ def raw_vv_collisions(T: float, idata: np.ndarray, Z_vibr1: float, Z_vibr2: floa
 
     for k in range(molecule_num_vibr2):
         for i in range(molecule_num_vibr1):
-            cs = raw_vv_integral(T, 0, idata, molecule_vibr_array1, molecule_vibr_exp_array2, i, k + 1, 1, nokt)
+            cs = raw_vv_integral(T, 0, mass, beta, vssc, vsso,
+                                 molecule_vibr_array1, molecule_vibr_exp_array2, i, k + 1, 1, nokt)
             result[0] += ((molecule_vibr_array1[i] -
                            molecule_vibr_array1[i + 1]) ** 2) * molecule_vibr_exp_array1[i]\
                                                               * molecule_vibr_exp_array2[k + 1] * cs
@@ -657,7 +692,8 @@ def raw_vv_collisions(T: float, idata: np.ndarray, Z_vibr1: float, Z_vibr2: floa
             result[10] -= molecule_vibr_exp_array1[i] * molecule_vibr_exp_array2[k + 1] * cs
             result[11] += molecule_vibr_exp_array1[i] * molecule_vibr_exp_array2[k + 1] * cs
 
-            cs = raw_vv_integral(T, 0, idata, molecule_vibr_array1, molecule_vibr_array2, i + 1, k, -1, nokt)
+            cs = raw_vv_integral(T, 0, mass, beta, vssc, vsso,
+                                 molecule_vibr_array1, molecule_vibr_array2, i + 1, k, -1, nokt)
             result[0] += ((molecule_vibr_array1[i] - molecule_vibr_array1[i + 1]) ** 2)\
                 * molecule_vibr_exp_array1[i + 1] * molecule_vibr_exp_array2[k] * cs
             result[1] += ((molecule_vibr_array2[k] - molecule_vibr_array2[k + 1]) ** 2)\
@@ -691,7 +727,8 @@ def raw_vv_collisions(T: float, idata: np.ndarray, Z_vibr1: float, Z_vibr2: floa
     return result / Z
 
 
-def raw_dE_rot_sq(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_symmetry: float, molecule_rot_const: float,
+def raw_dE_rot_sq(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+                  Z_rot: float, molecule_rot_symmetry: float, molecule_rot_const: float,
                   molecule_num_rot: int, full_integral: bool=True, nokt: bool=False) -> float:
     """Calculates either the partial averaging of the squared change in rotational energy
     over all one-quantum rotational transitions
@@ -703,8 +740,14 @@ def raw_dE_rot_sq(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_symmet
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_rot : float
         the value of the rotational partition function of the molecule
     molecule_rot_symmetry : float
@@ -740,10 +783,11 @@ def raw_dE_rot_sq(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_symmet
         return tmp * 0.5 / (Z_rot * ((constants.k * T) ** 2) * molecule_num_rot)
     else:
         return tmp * 0.5 / (Z_rot * ((constants.k * T) ** 2) * molecule_num_rot)\
-                   * elastic_integral(T, 0, idata, nokt=nokt)
+                   * elastic_integral(T, 0, sigma, mass, vssc, vsso, nokt=nokt)
 
 
-def raw_dE_rot_single(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_symmetry: float,
+def raw_dE_rot_single(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+                      Z_rot: float, molecule_rot_symmetry: float,
                       molecule_rot_const: float, molecule_num_rot: int, full_integral: bool=True,
                       nokt: bool=False) -> float:
     """Calculates either the partial averaging of the squared change in rotational energy
@@ -756,8 +800,14 @@ def raw_dE_rot_single(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_sy
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_rot : float
         the value of the rotational partition function of the molecule
     molecule_rot_symmetry : float
@@ -781,17 +831,25 @@ def raw_dE_rot_single(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_sy
                   * ((2.0 * j + 1.0) / molecule_rot_symmetry)\
                   * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
     tmp = integrate.quad(f, 0, molecule_num_rot - 1)[0]
+    # A = constants.k * T / molecule_rot_const
+    # tmp = (molecule_rot_const / molecule_rot_symmetry) * A * (A - np.exp(-molecule_num_rot * (molecule_num_rot - 1) / A)
+    #                                                           * (A + molecule_num_rot ** 2 - molecule_num_rot))
     f = lambda j: (j * (j + 1) * molecule_rot_const - (j - 1) * j * molecule_rot_const)\
                   * ((2.0 * j + 1.0) / molecule_rot_symmetry)\
                   * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
     tmp += integrate.quad(f, 1, molecule_num_rot)[0]
+    # tmp += (molecule_rot_const / molecule_rot_symmetry) * A\
+    #        * ((A + 2.0) * np.exp(-2.0 / A) - np.exp(-molecule_num_rot * (molecule_num_rot + 1) / A)
+    #                     * (A + molecule_num_rot ** 2 + molecule_num_rot))
     if full_integral is False:
         return tmp * 0.5 / (Z_rot * constants.k * T * molecule_num_rot)
     else:
-        return tmp * 0.5 / (Z_rot * constants.k * T * molecule_num_rot) * elastic_integral(T, 0, idata, nokt=nokt)
+        return tmp * 0.5 / (Z_rot * constants.k * T * molecule_num_rot)\
+                   * elastic_integral(T, 0, sigma, mass, vssc, vsso, nokt=nokt)
 
 
-def raw_dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: float, molecule_rot_symmetry1: float,
+def raw_dE_rot_c_dE_rot_d(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+                          Z_rot1: float, Z_rot2: float, molecule_rot_symmetry1: float,
                           molecule_rot_symmetry2: float, molecule_rot_const1: float, molecule_rot_const2: float,
                           molecule_num_rot1: int, molecule_num_rot2: int, full_integral: bool=True,
                           nokt: bool=False) -> float:
@@ -806,8 +864,14 @@ def raw_dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: fl
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_rot1 : float
         the value of the rotational partition function of the first molecule
     Z_rot2 : float
@@ -836,13 +900,14 @@ def raw_dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: fl
     float
         The calculated averaging
     """
-    return raw_dE_rot_single(T, idata, Z_rot1, molecule_rot_symmetry1, molecule_rot_const1, molecule_num_rot1,
-                             full_integral, nokt) * raw_dE_rot_single(T, idata, Z_rot2, molecule_rot_symmetry2,
-                                                                      molecule_rot_const2, molecule_num_rot2, False,
-                                                                      False)
+    return raw_dE_rot_single(T, sigma, mass, vssc, vsso, Z_rot1, molecule_rot_symmetry1, molecule_rot_const1,
+                             molecule_num_rot1, full_integral, nokt)\
+           * raw_dE_rot_single(T, sigma, mass, vssc, vsso, Z_rot2,
+                               molecule_rot_symmetry2, molecule_rot_const2, molecule_num_rot2, False, False)
 
 
-def raw_dE_rot_dE_rot_full(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: float, molecule_rot_symmetry1: float,
+def raw_dE_rot_dE_rot_full(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+                           Z_rot1: float, Z_rot2: float, molecule_rot_symmetry1: float,
                            molecule_rot_symmetry2: float, molecule_rot_const1: float, molecule_rot_const2: float,
                            molecule_num_rot1: int, molecule_num_rot2: int, full_integral: bool=True,
                            nokt: bool=False) -> float:
@@ -859,8 +924,14 @@ def raw_dE_rot_dE_rot_full(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: f
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_rot1 : float
         the value of the rotational partition function of the first molecule
     Z_rot2 : float
@@ -889,10 +960,10 @@ def raw_dE_rot_dE_rot_full(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: f
     float
         The calculated averaging
     """
-    return raw_dE_rot_sq(T, idata, Z_rot1, molecule_rot_symmetry1, molecule_rot_const1, molecule_num_rot1,
-                         full_integral, nokt) + raw_dE_rot_single(T, idata, Z_rot1, molecule_rot_symmetry1,
-                                                                  molecule_rot_const1, molecule_num_rot1, full_integral,
-                                                                  nokt) \
-                                                * raw_dE_rot_single(T, idata, Z_rot2, molecule_rot_symmetry2,
-                                                                    molecule_rot_const2, molecule_num_rot2, False,
-                                                                    False)
\ No newline at end of file
+    return raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot1, molecule_rot_symmetry1, molecule_rot_const1,
+                         molecule_num_rot1, full_integral, nokt)\
+           + raw_dE_rot_single(T, sigma, mass, vssc, vsso, Z_rot1, molecule_rot_symmetry1, molecule_rot_const1,
+                               molecule_num_rot1, full_integral, nokt) \
+                                                * raw_dE_rot_single(T, sigma, mass, vssc, vsso, Z_rot2,
+                                                                    molecule_rot_symmetry2, molecule_rot_const2,
+                                                                    molecule_num_rot2, False, False)
\ No newline at end of file
