@@ -266,7 +266,7 @@ def omega_vss(T: float, l: int, mass: float, vssc: float, vsso: float, nokt: boo
 
 
 def omega_dimensionless_esa(T: float, l: int, r: int, beta: float, eps: float) -> float:
-    """Returns the dimensionless :math:`\\Omega^{(l,r)}`-integral using ESA data
+    """Returns the dimensionless :math:`\\Omega^{(l,r)}`-integral calculated using ESA data
 
     Parameters
     ----------
