@@ -72,8 +72,7 @@ def vel_avg_vt(g: float, ve_before: float, ve_after: float, m: float) -> float:
         return 0.5 * (g + (gn_sq ** 0.5))
 
 
-def vel_avg_vv(g: float, ve_before1: float, ve_before2: float, ve_after1: float,
-               ve_after2: float, m: float) -> float:
+def vel_avg_vv(g: float, ve_before1: float, ve_after1: float, ve_before2: float, ve_after2: float, m: float) -> float:
     """Helper function, returns the arithmetic mean of the relative velocity of particles before and after
     a VV transition (using the energy conservation law) M1(i1) + M2(k1) -> M1(i2) + M2(k2)
 
@@ -109,8 +108,8 @@ def vel_avg_vv(g: float, ve_before1: float, ve_before2: float, ve_after1: float,
         return 0.5 * (g + (gn_sq ** 0.5))
 
 
-def vt_probability(g: float, T: float, idata: np.ndarray, molecule_vibr_array: np.ndarray, molecule_vibr_zero: float,
-                   molecule_diss: float,i: int, delta: int) -> float:
+def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float,
+                   molecule_vibr_zero: float, molecule_diss: float, i: int, delta: int) -> float:
     """Returns the probability of a VT transition using the FHO (Forced harmonic oscillator) model
      M(i) + P -> M(i + delta) + P
 
@@ -120,10 +119,14 @@ def vt_probability(g: float, T: float, idata: np.ndarray, molecule_vibr_array: n
         the relative dimensionless velocity of the particles before the collision
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
-    molecule_vibr_array1 : 1-D array-like
-        the array of vibrational energies of the molecule undergoing the VT transition
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    ve_before : float
+        the vibrational energy of the molecule before the transition
+    ve_after : float
+        the vibrational energy of the molecule after the transition
     molecule_vibr_zero : float
         the energy of the 0-th vibrational level
     molecule_diss : float
@@ -147,24 +150,24 @@ def vt_probability(g: float, T: float, idata: np.ndarray, molecule_vibr_array: n
         s = -delta * 1.0
         ns = fact_div_fact(i + delta, i)
 
-    omega = np.absolute((molecule_vibr_array[i] - molecule_vibr_array[i + delta]) / delta) / constants.hbar
+    omega = np.absolute((ve_before - ve_after) / delta) / constants.hbar
     if omega == 0.0:
         return 0.0
-    g *= (2 * constants.k * T / idata[0]) ** 0.5  # convert to dimensional velocity
-    vel = vel_avg_vt(g, molecule_vibr_array[i], molecule_vibr_array[i + delta], idata[0])
+    g *= (2 * constants.k * T / mass) ** 0.5
+    vel = vel_avg_vt(g, ve_before, ve_after, mass)
 
     if vel < 0.0:
         return 0.0
-    phi = 2.0 * np.arctan(((2.0 * (molecule_diss + molecule_vibr_zero) / idata[0]) ** 0.5) / vel)
+    phi = 2.0 * np.arctan(((2.0 * (molecule_diss + molecule_vibr_zero) / mass) ** 0.5) / vel)
 
-    eps = (np.cosh((1.0 + phi) * omega / (idata[4] * vel))
-           / (np.sinh(2.0 * constants.pi * omega / (idata[4] * vel)))) ** 2
-    eps *= 4.0 * svt * (constants.pi ** 2) * omega * idata[0] / ((idata[4] ** 2) * constants.h)
+    eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
+           / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+    eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
     prob = ns * (eps ** s) * np.exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1)) / (factorial(s) ** 2)
     return prob
 
 
-def vt_prob_g_only(g: float, T: float, idata: np.ndarray, molecule_vibr_array: np.ndarray, i: int, delta: int,
+def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float, i: int, delta: int,
                    depth: float) -> float:
     """Returns the velocity-dependent part of the probability of a VT transition using
     the FHO (Forced harmonic oscillator) model M(i) + P -> M(i + delta) + P
@@ -175,10 +178,14 @@ def vt_prob_g_only(g: float, T: float, idata: np.ndarray, molecule_vibr_array: n
         the relative dimensionless velocity of the particles before the collision
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
-    vibr_spec : 1-D array-like
-        the array of the vibrational energies of the molecule undergoing the VT transition
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    ve_before : float
+        the vibrational energy of the molecule before the transition
+    ve_after : float
+        the vibrational energy of the molecule after the transition
     i : int
         the vibrational level of the molecule
     delta : int
@@ -193,50 +200,49 @@ def vt_prob_g_only(g: float, T: float, idata: np.ndarray, molecule_vibr_array: n
     """
     svt = 0.5
 
-    g *= (2 * constants.k * T / idata[0]) ** 0.5  # convert to dimensional velocity
-    vel = vel_avg_vt(g, molecule_vibr_array[i], molecule_vibr_array[i + delta], idata[0])
+    g *= (2 * constants.k * T / mass) ** 0.5
+    vel = vel_avg_vt(g, ve_before, ve_after, mass)
     if vel < 0.0:
         return 0.0
 
     if delta == 1:
-        omega = (molecule_vibr_array[i + 1] - molecule_vibr_array[i]) / constants.hbar
-        phi = 2.0 * np.arctan(((2.0 * depth / idata[0]) ** 0.5) / vel)
+        omega = (ve_after - ve_before) / constants.hbar
+        phi = 2.0 * np.arctan(((2.0 * depth / mass) ** 0.5) / vel)
 
-        eps = (np.cosh((1.0 + phi) * omega / (idata[4] * vel))
-               / (np.sinh(2.0 * constants.pi * omega / (idata[4] * vel)))) ** 2
-        eps *= 4.0 * svt * (constants.pi ** 2) * omega * idata[0] / ((idata[4] ** 2) * constants.h)
+        eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
+               / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+        eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
         return eps * np.exp(-(i + 1) * eps)
     elif delta == -1:
-        omega = (molecule_vibr_array[i] - molecule_vibr_array[i - 1]) / constants.hbar
-        phi = 2.0 * np.arctan(((2.0 * depth / idata[0]) ** 0.5) / vel)
+        omega = (ve_before - ve_after) / constants.hbar
+        phi = 2.0 * np.arctan(((2.0 * depth / mass) ** 0.5) / vel)
 
-        eps = (np.cosh((1.0 + phi) * omega / (idata[4] * vel))
-               / (np.sinh(2.0 * constants.pi * omega / (idata[4] * vel)))) ** 2
-        eps *= 4.0 * svt * (constants.pi ** 2) * omega * idata[0] / ((idata[4] ** 2) * constants.h)
+        eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
+               / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+        eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
         return eps * np.exp(-i * eps)
     elif delta > 0:
         s = delta * 1.0
-        omega = (molecule_vibr_array[i + delta] - molecule_vibr_array[i]) / (delta * constants.hbar)
+        omega = (ve_after - ve_before) / (delta * constants.hbar)
         ns = fact_div_fact(i, i + delta)
-        phi = 2.0 * np.arctan(((2.0 * depth / idata[0]) ** 0.5) / vel)
-        eps = (np.cosh((1.0 + phi) * omega / (idata[4] * vel))
-               / (np.sinh(2.0 * constants.pi * omega / (idata[4] * vel)))) ** 2
-        eps *= 4.0 * svt * (constants.pi ** 2) * omega * idata[0] / ((idata[4] ** 2) * constants.h)
+        phi = 2.0 * np.arctan(((2.0 * depth / mass) ** 0.5) / vel)
+        eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
+               / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+        eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
         return (eps ** s) * np.exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
     else:
         s = -delta * 1.0
-        omega = (molecule_vibr_array[i + delta] - molecule_vibr_array[i]) / (delta * constants.hbar)
+        omega = (ve_before - ve_after) / (delta * constants.hbar)
         ns = fact_div_fact(i + delta, i)
-        phi = 2.0 * np.arctan(((2.0 * depth / idata[0]) ** 0.5) / vel)
-        eps = (np.cosh((1.0 + phi) * omega / (idata[4] * vel))
-               / (np.sinh(2.0 * constants.pi * omega / (idata[4] * vel)))) ** 2
-        eps *= 4.0 * svt * (constants.pi ** 2) * omega * idata[0] / ((idata[4] ** 2) * constants.h)
+        phi = 2.0 * np.arctan(((2.0 * depth / mass) ** 0.5) / vel)
+        eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
+               / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
+        eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
         return (eps ** s) * np.exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
 
 
-def vv_probability(g: float, T: float, idata: np.ndarray, molecule_vibr_array1: np.ndarray,
-                   molecule_vibr_array2: np.ndarray, i: int,
-                   k: int, i_delta: int) -> float:
+def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
+                   ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
     """Returns the probability of a VV transition using the FHO (Forced harmonic oscillator) model
      M1(i) + M2(k) -> M1(i + delta) + M2(k - i_delta)
 
@@ -246,12 +252,18 @@ def vv_probability(g: float, T: float, idata: np.ndarray, molecule_vibr_array1:
         the relative dimensionless velocity of the particles before the collision
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
-    molecule_vibr_array1 : 1-D array-like
-        the array of vibrational energies of the first molecule undergoing the VV transition
-    molecule_vibr_array2 : 1-D array-like
-        the array of vibrational energies of the second molecule undergoing the VV transition
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    ve_before1 : float
+        the vibrational energy of the molecule M1 before the transition
+    ve_after1 : float
+        the vibrational energy of the molecule M1 after the transition
+    ve_before2 : float
+        the vibrational energy of the molecule M2 before the transition
+    ve_after2 : float
+        the vibrational energy of the molecule M2 after the transition
     i : int
         the vibrational level of molecule1
     k : int
@@ -275,33 +287,29 @@ def vv_probability(g: float, T: float, idata: np.ndarray, molecule_vibr_array1:
         ns1 = fact_div_fact(i + i_delta, i)
         ns2 = fact_div_fact(k, k - i_delta)
 
-    g *= (2.0 * constants.k * T / idata[0]) ** 0.5
-    vel = vel_avg_vv(g, molecule_vibr_array1[i], molecule_vibr_array2[k], molecule_vibr_array1[i + i_delta],
-                     molecule_vibr_array2[k - i_delta],
-                     idata[0])
+    g *= (2.0 * constants.k * T / mass) ** 0.5
+    vel = vel_avg_vv(g, ve_before1, ve_after2, ve_before2, ve_after2, mass)
 
     if vel < 0:
         return 0.0
-    omega1 = np.absolute((molecule_vibr_array1[i] -
-                          molecule_vibr_array1[i + i_delta]) / i_delta) / constants.hbar
 
-    omega2 = np.absolute((molecule_vibr_array2[k] -
-                          molecule_vibr_array2[k - i_delta]) / i_delta) / constants.hbar
+    omega1 = np.absolute((ve_before1 - ve_after1) / i_delta) / constants.hbar
+    omega2 = np.absolute((ve_before2 - ve_after2) / i_delta) / constants.hbar
 
     if omega1 == 0.0 or omega2 == 0:
         return 0.0
-    xi = 2 * np.abs(omega1 - omega2) / (idata[4] * vel)
+
+    xi = 2 * np.abs(omega1 - omega2) / (beta * vel)
     if xi < 1.0 ** (-4):
-        rhoxi = 0.25 * svv * ((idata[4] * vel) ** 2) / (omega1 * omega2)
+        rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
     else:
         rhoxi = svv * (np.abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
 
     return rhoxi * ns1 * ns2 * np.exp(-2.0 * rhoxi * ((ns1 * ns2) ** (1.0 / s)) / (s + 1)) / (factorial(s) ** 2)
 
 
-def vv_prob_g_only(g: float, T: float, idata: np.ndarray, molecule_vibr_array1: np.ndarray,
-                   molecule_vibr_array2: np.ndarray, i: int,
-                   k: int, i_delta: int) -> float:
+def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
+                   ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
     """Returns the velocity-dependent part of the probability of a VV transition using the FHO
     (Forced harmonic oscillator) model M1(i) + M2(k) -> M1(i + delta) + M2(k - i_delta)
 
@@ -311,12 +319,18 @@ def vv_prob_g_only(g: float, T: float, idata: np.ndarray, molecule_vibr_array1:
         the relative dimensionless velocity of the particles before the collision
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
-    molecule_vibr_array1 : 1-D array-like
-        the array of vibrational energies of the first molecule undergoing the VV transition
-    molecule_vibr_array2 : 1-D array-like
-        the array of vibrational energies of the second molecule undergoing the VV transition
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    beta : float
+        the IPL :math:`\\beta` parameter
+    ve_before1 : float
+        the vibrational energy of the molecule M1 before the transition
+    ve_after1 : float
+        the vibrational energy of the molecule M1 after the transition
+    ve_before2 : float
+        the vibrational energy of the molecule M2 before the transition
+    ve_after2 : float
+        the vibrational energy of the molecule M2 after the transition
     i : int
         the vibrational level of molecule1
     k : int
@@ -330,41 +344,40 @@ def vv_prob_g_only(g: float, T: float, idata: np.ndarray, molecule_vibr_array1:
         Velocity-dependent part of the VV transition probability
     """
     svv = 0.04
-    g *= (2.0 * constants.k * T / idata[0]) ** 0.5
-    vel = vel_avg_vv(g, molecule_vibr_array1[i], molecule_vibr_array2[k], molecule_vibr_array1[i + i_delta], molecule_vibr_array2[k - i_delta], idata[0])
+    g *= (2.0 * constants.k * T / mass) ** 0.5
+    vel = vel_avg_vv(g, ve_before1, ve_after2, ve_before2, ve_after2, mass)
     if vel < 0:
         return 0.0
 
     if i_delta == 1:
-        omega1 = (molecule_vibr_array1[i + 1] - molecule_vibr_array1[i]) / constants.hbar
-        omega2 = (molecule_vibr_array2[k] - molecule_vibr_array2[k - 1]) / constants.hbar
-        xi = 2.0 * np.abs(omega1 - omega2) / (idata[4] * vel)
+        omega1 = (ve_after1 - ve_before1) / constants.hbar
+        omega2 = (ve_before2 - ve_after2) / constants.hbar
+        xi = 2.0 * np.abs(omega1 - omega2) / (beta * vel)
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((idata[4] * vel) ** 2) / (omega1 * omega2)
+            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
             rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
 
         return rhoxi * np.exp(-((i + 1) * k) * rhoxi)
     elif i_delta == -1:
-        omega1 = (molecule_vibr_array1[i] - molecule_vibr_array1[i - 1]) / constants.hbar
-        omega2 = (molecule_vibr_array2[k + 1] - molecule_vibr_array2[k]) / constants.hbar
+        omega1 = (ve_before1 - ve_after1) / constants.hbar
+        omega2 = (ve_after2 - ve_before2) / constants.hbar
+        xi = 2.0 * np.abs(omega1 - omega2) / (beta * vel)
 
-        xi = 2.0 * np.abs(omega1 - omega2) / (idata[4] * vel)
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((idata[4] * vel) ** 2) / (omega1 * omega2)
+            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
             rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
 
         return rhoxi * np.exp(-(i * (k + 1)) * rhoxi)
     elif i_delta > 0:
         s = i_delta * 1.0
+        omega1 = (ve_after1 - ve_before1) / constants.hbar
+        omega2 = (ve_before2 - ve_after2) / constants.hbar
+        xi = 2.0 * np.abs(omega1 - omega2) / (beta * vel)
 
-        omega1 = (molecule_vibr_array1[i + i_delta] - molecule_vibr_array1[i]) / (i_delta * constants.hbar)
-        omega2 = (molecule_vibr_array2[k] - molecule_vibr_array2[k - i_delta]) / (i_delta * constants.hbar)
-
-        xi = 2.0 * np.abs(omega1 - omega2) / (idata[4] * vel)
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((idata[4] * vel) ** 2) / (omega1 * omega2)
+            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
             rhoxi = svv * (np.abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
 
@@ -372,13 +385,12 @@ def vv_prob_g_only(g: float, T: float, idata: np.ndarray, molecule_vibr_array1:
                      * rhoxi / (s + 1))
     else:
         s = -i_delta * 1.0
+        omega1 = (ve_before1 - ve_after1) / constants.hbar
+        omega2 = (ve_after2 - ve_before2) / constants.hbar
+        xi = 2.0 * np.abs(omega1 - omega2) / (beta * vel)
 
-        omega1 = (molecule_vibr_array1[i + i_delta] - molecule_vibr_array1[i]) / (i_delta * constants.hbar)
-        omega2 = (molecule_vibr_array2[k] - molecule_vibr_array2[k - i_delta]) / (i_delta * constants.hbar)
-
-        xi = 2.0 * np.abs(omega1 - omega2) / (idata[4] * vel)
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((idata[4] * vel) ** 2) / (omega1 * omega2)
+            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
             rhoxi = svv * (np.abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
 
