@@ -92,7 +92,8 @@ def diss_rate_rigid_sphere(T: float, idata: np.ndarray, molecule: MoleculeSTS, i
     float
         Non-equilibrium dissociation rate constant
     """
-    return raw_diss_rate_rigid_sphere(T, idata, molecule.vibr[i], molecule.diss, center_of_mass, vl_dependent)
+    return raw_diss_rate_rigid_sphere(T, idata[1], idata[0], molecule.vibr[i], molecule.diss, center_of_mass,
+                                      vl_dependent)
 
 
 def raw_diss_rate_treanor_marrone(T: float, model_data: np.ndarray, Z_diss: float, molecule_diss: float) -> float:
@@ -118,7 +119,7 @@ def raw_diss_rate_treanor_marrone(T: float, model_data: np.ndarray, Z_diss: floa
     return Z_diss * k_diss_eq(T, model_data, molecule_diss)
 
 
-def raw_diss_rate_rigid_sphere(T: float, idata: np.ndarray, molecule_vibr: float, molecule_diss: float,
+def raw_diss_rate_rigid_sphere(T: float, sigma: float, mass: float, molecule_vibr: float, molecule_diss: float,
                                center_of_mass: bool=True, vl_dependent: bool=True) -> float:
     """Calculates the non-equilibrium rate constant using the rigid-sphere crosssection
 
@@ -126,8 +127,10 @@ def raw_diss_rate_rigid_sphere(T: float, idata: np.ndarray, molecule_vibr: float
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates
     molecule_diss : float
@@ -144,5 +147,5 @@ def raw_diss_rate_rigid_sphere(T: float, idata: np.ndarray, molecule_vibr: float
     float
         Non-equilibrium dissociation rate constant
     """
-    return 8.0 * raw_diss_integral_rigid_sphere(T, 0, idata, molecule_vibr, molecule_diss, center_of_mass, vl_dependent,
-                                                False)
\ No newline at end of file
+    return 8.0 * raw_diss_integral_rigid_sphere(T, 0, sigma, mass, molecule_vibr, molecule_diss, center_of_mass,
+                                                vl_dependent, False)
\ No newline at end of file
