@@ -73,12 +73,14 @@ def rot_tel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner
         Rotational relaxation time
     """
     if isinstance(partner, MoleculeSTS):
-        return raw_rot_tel_time_def_molecule_partner(T, idata, molecule.Z_rot(T), partner.Z_rot(T),
+        return raw_rot_tel_time_def_molecule_partner(T, idata[1], idata[0], idata[9], idata[10],
+                                                     molecule.Z_rot(T), partner.Z_rot(T),
                                                      molecule.rot_symmetry, partner.rot_symmetry, molecule.rot_const,
                                                      partner.rot_const, molecule.num_rot, partner.num_rot,
                                                      molecule.name, partner.name, n)
     else:
-        return raw_rot_tel_time_def_atom_partner(T, idata, molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const,
+        return raw_rot_tel_time_def_atom_partner(T, idata[1], idata[0], idata[9], idata[10],
+                                                 molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const,
                                                  molecule.num_rot, n)
 
 
@@ -138,7 +140,6 @@ def millikan_white(T: float, idata: np.ndarray, molecule: MoleculeSTS, p: float)
                      * (T ** (-1.0 / 3.0) - 0.015 * (mu ** 0.25)) - 8.0)) / p
 
 
-
 def Zr_original(T: float, eps: float, infcoll: float) -> float:
     """
     Calculates the collision amount needed to reach rotational equilibrium for the hard sphere model, but has an
@@ -243,7 +244,8 @@ def raw_rot_rel_time(T: float, idata: np.ndarray, eps: float, n: float, infcoll:
         / (n * omega(T, 2, 2, idata, model=model, nokt=False))  # 0.15625 is 5 / 32
 
 
-def raw_rot_tel_time_def_molecule_partner(T: float, idata: np.ndarray, Z_rot1: float, Z_rot2: float,
+def raw_rot_tel_time_def_molecule_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+                                          Z_rot1: float, Z_rot2: float,
                                           molecule_rot_symmetry1: float, molecule_rot_symmetry2: float,
                                           molecule_rot_const1: float, molecule_rot_const2: float,
                                           molecule_num_rot1: int, molecule_num_rot2: int, molecule_name: str,
@@ -255,8 +257,14 @@ def raw_rot_tel_time_def_molecule_partner(T: float, idata: np.ndarray, Z_rot1: f
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_rot1 : float
         the value of the rotational partition function of the first molecule
     Z_rot2 : float
@@ -289,21 +297,22 @@ def raw_rot_tel_time_def_molecule_partner(T: float, idata: np.ndarray, Z_rot1: f
     """
 
     if molecule_name == partner_name:
-        return 0.5 / (n * cs.elastic_integral(T, 0, idata)
-                      * (2 * cs.raw_dE_rot_sq(T, idata, Z_rot1, molecule_rot_symmetry1, molecule_rot_const1,
-                                              molecule_num_rot1, False, False)
-                         + 2 * cs.raw_dE_rot_c_dE_rot_d(T, idata, Z_rot1, Z_rot2, molecule_rot_symmetry1,
-                                                        molecule_rot_symmetry2, molecule_rot_const1,
-                                                        molecule_rot_const2, molecule_num_rot1, molecule_num_rot2,
-                                                        False, False)))
+        return 0.5 / (n * cs.elastic_integral(T, 0, sigma, mass, vssc, vsso)
+                      * (2 * cs.raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot1, molecule_rot_symmetry1,
+                                              molecule_rot_const1, molecule_num_rot1, False, False)
+                         + 2 * cs.raw_dE_rot_c_dE_rot_d(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2,
+                                                        molecule_rot_symmetry1, molecule_rot_symmetry2,
+                                                        molecule_rot_const1, molecule_rot_const2,
+                                                        molecule_num_rot1, molecule_num_rot2, False, False)))
     else:
-        return 0.25 / (n * cs.elastic_integral(T, 0, idata)
-                       * cs.raw_dE_rot_dE_rot_full(T, idata, Z_rot1, Z_rot2, molecule_rot_symmetry1,
+        return 0.25 / (n * cs.elastic_integral(T, 0, sigma, mass, vssc, vsso)
+                       * cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2, molecule_rot_symmetry1,
                                                    molecule_rot_symmetry2, molecule_rot_const1, molecule_rot_const2,
                                                    molecule_num_rot1, molecule_num_rot2, False, False))
         
         
-def raw_rot_tel_time_def_atom_partner(T: float, idata: np.ndarray, Z_rot: float, molecule_rot_symmetry: float,
+def raw_rot_tel_time_def_atom_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+                                      Z_rot: float, molecule_rot_symmetry: float,
                                       molecule_rot_const: float, molecule_num_rot: int, n: float) -> float:
     """ Calculates the rotational relaxation time using the definition (through the averaging of the squared
     rotational energy difference), *raw* version for the case when the partner is an atom
@@ -312,8 +321,14 @@ def raw_rot_tel_time_def_atom_partner(T: float, idata: np.ndarray, Z_rot: float,
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_rot : float
         the value of the rotational partition function of the molecule
     molecule_rot_symmetry : float
@@ -331,6 +346,6 @@ def raw_rot_tel_time_def_atom_partner(T: float, idata: np.ndarray, Z_rot: float,
     float
         Rotational relaxation time
     """
-    return 0.25 / (n * cs.elastic_integral(T, 0, idata)
-                   * cs.raw_dE_rot_sq(T, idata, Z_rot, molecule_rot_symmetry, molecule_rot_const, molecule_num_rot,
-                                      False, False))
\ No newline at end of file
+    return 0.25 / (n * cs.elastic_integral(T, 0, sigma, mass, vssc, vsso)
+                   * cs.raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot, molecule_rot_symmetry,
+                                      molecule_rot_const, molecule_num_rot, False, False))
\ No newline at end of file
